% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/wfs-mars-reg.R
\name{ts_wfs_mars}
\alias{ts_wfs_mars}
\title{Auto MARS (Earth) Workflowset Function}
\usage{
ts_wfs_mars(
  .model_type = "earth",
  .recipe_list,
  .num_terms = 200,
  .prod_degree = 1,
  .prune_method = "backward"
)
}
\arguments{
\item{.model_type}{This is where you will set your engine. It uses
\code{\link[parsnip:mars]{parsnip::mars()}} under the hood and can take one of the following:
\itemize{
\item "earth"
}}

\item{.recipe_list}{You must supply a list of recipes. list(rec_1, rec_2, ...)}

\item{.num_terms}{The number of features that will be retained in the final
model, including the intercept.}

\item{.prod_degree}{The highest possible interaction degree.}

\item{.prune_method}{The pruning method. This is a character, the default is
"backward". You can choose from one of the following:
\itemize{
\item "backward"
\item "none"
\item "exhaustive"
\item "forward"
\item "seqrep"
\item "cv"
}}
}
\value{
Returns a workflowsets object.
}
\description{
This function is used to quickly create a workflowsets object.
}
\details{
This function expects to take in the recipes that you want to use in
the modeling process. This is an automated workflow process. There are sensible
defaults set for the model specification, but if you choose you can set them
yourself if you have a good understanding of what they should be. The mode is
set to "regression".

This only uses the option \code{set_engine("earth")} and therefore the .model_type
is not needed. The parameter is kept because it is possible in the future that
this could change, and it keeps with the framework of how other functions
are written.
}
\examples{
suppressPackageStartupMessages(library(modeltime))
suppressPackageStartupMessages(library(timetk))
suppressPackageStartupMessages(library(dplyr))
suppressPackageStartupMessages(library(rsample))

data <- AirPassengers \%>\%
  ts_to_tbl() \%>\%
  select(-index)

splits <- time_series_split(
   data
  , date_col
  , assess = 12
  , skip = 3
  , cumulative = TRUE
)

rec_objs <- ts_auto_recipe(
 .data = training(splits)
 , .date_col = date_col
 , .pred_col = value
)

wf_sets <- ts_wfs_mars("earth", rec_objs)
wf_sets

}
\seealso{
\url{https://workflowsets.tidymodels.org/}

\url{https://parsnip.tidymodels.org/reference/mars.html}

Other Auto Workflowsets: 
\code{\link{ts_wfs_arima_boost}()},
\code{\link{ts_wfs_auto_arima}()},
\code{\link{ts_wfs_ets_reg}()},
\code{\link{ts_wfs_lin_reg}()},
\code{\link{ts_wfs_nnetar_reg}()},
\code{\link{ts_wfs_prophet_reg}()},
\code{\link{ts_wfs_svm_poly}()},
\code{\link{ts_wfs_svm_rbf}()},
\code{\link{ts_wfs_xgboost}()}
}
\author{
Steven P. Sanderson II, MPH
}
\concept{Auto Workflowsets}
